/* AppGlobal.java
 *
 * created: Fri May 19 2000
 *
 * This file is part of Artemis
 *
 * Copyright (C) 2000  Genome Research Limited
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Header: /nfs/pathsoft/repository/artemis_applet_impl/AppGlobal.java,v 1.3 2001/06/28 12:05:42 kmr Exp $
 */

import uk.ac.sanger.pathogens.*;

import diana.*;

import java.io.*;
import java.awt.*;

/**
 *  This class contains static methods that are needed by all the programs
 *  based on Artemis.  Each application needs to implement these methods
 *  appropriately.
 *
 *  @author Kim Rutherford <kmr@sanger.ac.uk>
 *  @version $Id: AppGlobal.java,v 1.3 2001/06/28 12:05:42 kmr Exp $
 **/

public class AppGlobal {
  /**
   *  Returns true for applets.
   **/
  public static boolean isApplet () {
    return true;
  }

  /**
   *  This method is a hack to get around a bug in Netscape.
   **/
  public static InputStream getFileFromJar (final String file_name) {
    final String buffer;

    if (file_name.equals ("etc/options")) {
      buffer =
        "font_size = 12\n" +
        "font_name = Monospaced\n" +
        "minimum_orf_size = 100\n" +
        "start_codons = atg\n" +
        "font_name = Monospaced\n" +
        "direct_edit = no\n" +
        "organism_type = eukaryote\n" +
        "eukaryotic_start_codons = atg\n" +
        "prokaryotic_start_codons = atg gtg ttg\n" +
        "colour_0 = 255 255 255\n" +
        "colour_1 = 100 100 100\n" +
        "colour_2 = 255 0 0\n" +
        "colour_3 = 0 255 0\n" +
        "colour_4 = 0 0 255\n" +
        "colour_5 = 0 255 255\n" +
        "colour_6 = 255 0 255\n" +
        "colour_7 = 255 255 0\n" +
        "colour_8 = 152 251 152\n" +
        "colour_9 = 135 206 250\n" +
        "colour_10 = 255 165 0\n" +
        "colour_11 = 200 150 100\n" +
        "colour_12 = 255 200 200\n" +
        "colour_13 = 170 170 170\n" +
        "colour_14 = 0 0 0\n" +
        "colour_15 = 255  63  63\n" +
        "colour_16 = 255 127 127\n" +
        "colour_17 = 255 191 191\n" +
        "colour_of_CDS = 5\n" +
        "colour_of_cds? = 7\n" +
        "colour_of_BLASTCDS = 2\n" +
        "colour_of_BLASTN_HIT = 6\n" +
        "colour_of_CRUNCH_D = 2\n" +
        "colour_of_source = 0\n" +
        "colour_of_prim_tran = 0\n" +
        "colour_of_stem_loop = 2\n" +
        "colour_of_misc_feature = 3\n" +
        "colour_of_misc_RNA = 12\n" +
        "colour_of_delta = 3\n" +
        "colour_of_LTR = 4\n" +
        "colour_of_repeat_region = 9\n" +
        "colour_of_repeat_unit = 9\n" +
        "colour_of_terminator = 3\n" +
        "colour_of_promoter = 3\n" +
        "colour_of_intron = 1\n" +
        "colour_of_exon = 7\n" +
        "colour_of_mRNA = 1\n" +
        "colour_of_tRNA = 8\n" +
        "colour_of_TATA = 3\n" +
        "colour_of_bldA = 2\n" +
        "colour_of_GFF = 11\n" +
        "colour_of_start_codon = 6\n" +
        "show_list = yes\n" +
        "show_results = no\n" +
        "draw_feature_borders = yes\n" +
        "draw_feature_arrows = yes\n" +
        "sanger_options = no\n" +
        "extra_keys = BLASTN_HIT CDS_BEFORE CDS_AFTER CDS_before CDS_after CDS_motif BLASTCDS polymorphism GFF WUBLASTN_HIT WUBLASTX_HIT BLASTX_HIT TBLASTX_HIT BLASTN_HIT CRUNCH_D CRUNCH_X fasta_record\n" +
        "extra_qualifiers = label text colour text class \"text\" gene \"text\" gff_seqname text gff_feature text gff_source text gff_group text blast_score text subject_id text query_id text subject_start text subject_end text percent_id text score text hp_match \"text\" fasta_match \"text\" blastp_match \"text\" pfam_match \"text\" prosite_match \"text\" gene_id \"text\" cds_id \"text\" created \"text\" modified \"text\" exon_id \"text\" start_phase text end_phase text interpro \"text\" GO_function \"text\" GO_process \"text\" GO_component \"text\" assembly_id \"text\" systematic_id \"text\" literature \"text\" interaction \"text\" mutation \"text\" domain \"text\" similarity \"text\"\n" +
        "invisible_qualifiers = fasta_file blast_file blastx_file blastn_file blastp_file blastp+go_file tblastn_file tblastx_file bicsw_file hth_file sigcleave_file pepstats_file smart_file gene_id cds_id created modified exon_id start_phase end_phase gff_seqname gff_feature gff_source gff_group query_id\n" +
        "feature_protein_programs =  fasta %SNTU  sigcleave 0  blast swir  blastp swir  tblastn embl_other  hth - \n" +
        "feature_dna_programs = tblastx embl_other blastn embl_other blastx swir\n" +
        "common_keys = allele attenuator CDS conflict exon intron LTR misc_feature misc_RNA mRNA mutation polyA_signal polyA_site promoter protein_bind RBS repeat_region repeat_unit rRNA scRNA snRNA source stem_loop STS TATA_signal terminator tRNA unsure variation -10_signal -35_signal CDS_motif gene BLASTN_HIT CDS_BEFORE CDS_AFTER BLASTCDS \n";
    } else {
      if (file_name.equals ("etc/feature_keys")) {
        buffer =
          "allele          citation db_xref frequency gene label map note partial phenotype product standard_name usedin replace\n" +
          "attenuator      citation db_xref evidence label gene map note partial phenotype usedin\n" +
          "C_region        citation db_xref evidence gene label map note partial product pseudo standard_name usedin\n" +
          "CAAT_signal     citation db_xref evidence label gene map note partial usedin\n" +
          "CDS             citation codon codon_start db_xref EC_number evidence exception function gene label map note number partial product protein_id pseudo standard_name translation transl_except transl_table usedin\n" +
          "conflict        @citation db_xref label map note gene usedin replace\n" +
          "D-loop          citation db_xref evidence label gene map note partial usedin\n" +
          "D_segment       citation db_xref evidence gene label map note partial product pseudo standard_name usedin\n" +
          "enhancer        citation db_xref evidence label gene map note partial standard_name usedin\n" +
          "exon            citation db_xref EC_number evidence function gene label map note number partial product pseudo standard_name usedin\n" +
          "GC_signal       citation db_xref evidence gene label map note partial usedin\n" +
          "gene            allele citation db_xref evidence function label map note partial product pseudo phenotype standard_name usedin\n" +
          "iDNA            citation db_xref evidence function label gene map note number partial standard_name usedin\n" +
          "intron          citation cons_splice db_xref evidence function gene label map note number partial standard_name usedin\n" +
          "J_segment       citation db_xref evidence gene map note partial product pseudo standard_name usedin\n" +
          "LTR citation    db_xref evidence function gene label map note partial standard_name usedin\n" +
          "mat_peptide     citation db_xref EC_number evidence function gene label map note partial product pseudo standard_name usedin\n" +
          "misc_binding    @bound_moiety citation db_xref evidence function gene label map note partial usedin\n" +
          "misc_difference citation db_xref gene label map clone partial note standard_name usedin replace\n" +
          "misc_feature    citation db_xref evidence function gene label map note partial number phenotype product pseudo standard_name usedin\n" +
          "misc_recomb     @organism citation db_xref evidence gene label map note partial standard_name usedin\n" +
          "misc_RNA        citation db_xref evidence function gene label map note partial product standard_name usedin\n" +
          "misc_signal     citation db_xref evidence function gene label map note partial phenotype standard_name usedin\n" +
          "misc_structure  citation db_xref evidence function gene label map note partial standard_name usedin\n" +
          "modified_base   @mod_base citation db_xref evidence frequency gene label map note usedin\n" +
          "mRNA            citation db_xref evidence exception function gene label map note partial product pseudo standard_name usedin\n" +
          "mutation        citation db_xref frequency gene label map note phenotype product standard_name usedin replace\n" +
          "N_region        citation db_xref evidence gene label map note partial product pseudo standard_name usedin\n" +
          "old_sequence    @citation db_xref gene label map note partial usedin replace\n" +
          "polyA_signal    citation db_xref evidence gene label map note partial usedin\n" +
          "polyA_site      citation db_xref evidence gene label map note usedin\n" +
          "precursor_RNA   citation db_xref evidence function gene label map note partial standard_name usedin\n" +
          "prim_transcript citation db_xref evidence function gene label map note partial standard_name usedin\n" +
          "primer_bind     citation db_xref evidence gene label map note partial standard_name PCR_conditions usedin\n" +
          "promoter        citation db_xref evidence function gene label map note partial phenotype pseudo standard_name usedin\n" +
          "protein_bind    @bound_moiety citation db_xref evidence function gene label map partial note standard_name usedin\n" +
          "RBS citation    db_xref evidence gene label map note partial standard_name usedin pseudo qualifier deleted v1.04\n" +
          "repeat_region   citation db_xref evidence function gene label map note partial rpt_family rpt_type rpt_unit standard_name usedin\n" +
          "repeat_unit     citation db_xref evidence function gene label map note partial rpt_family rpt_type rpt_unit usedin\n" +
          "rep_origin      citation db_xref direction evidence gene label map note partial standard_name usedin\n" +
          "rRNA citation   db_xref evidence function gene label map note partial product pseudo standard_name usedin\n" +
          "S_region        citation db_xref evidence gene label map note partial product pseudo standard_name usedin\n" +
          "satellite       citation db_xref evidence gene label map note partial rpt_type rpt_family rpt_unit standard_name usedin\n" +
          "scRNA           citation db_xref evidence function gene label map note partial product pseudo standard_name usedin\n" +
          "sig_peptide     citation db_xref evidence function gene label map note partial product pseudo standard_name usedin\n" +
          "snRNA           citation db_xref evidence function gene label map note partial product pseudo standard_name usedin\n" +
          "source          @organism cell_line cell_type chloroplast chromoplast chromosome citation clone clone_lib cultivar cyanelle db_xref dev_stage focus frequency germline haplotype lab_host insertion_seq isolate kinetoplast label macronuclear map mitochondrion note plasmid pop_variant proviral rearranged sequenced_mol serotype sex specimen_voucher specific_host strain sub_clone sub_species sub_strain tissue_lib tissue_type transposon usedin variety virion\n" +
          "stem_loop       citation db_xref evidence function gene label map note partial standard_name usedin\n" +
          "STS             citation db_xref standard_name gene label usedin note partial map\n" +
          "TATA_signal     citation db_xref evidence gene label map note partial usedin\n" +
          "terminator      citation db_xref evidence gene label map note partial standard_name usedin\n" +
          "transit_peptide citation db_xref evidence function gene label map note partial product pseudo standard_name usedin\n" +
          "tRNA            anticodon citation db_xref evidence function gene label map note partial product pseudo standard_name usedin\n" +
          "unsure          citation db_xref gene usedin label map note replace\n" +
          "V_region        citation db_xref evidence gene label map note partial product pseudo standard_name usedin\n" +
          "V_segment       citation db_xref evidence gene label map note partial product pseudo standard_name usedin\n" +
          "variation       citation db_xref frequency gene label map note partial phenotype product standard_name usedin replace\n" +
          "3'clip          citation db_xref evidence function gene label map note partial standard_name usedin\n" +
          "3'UTR           citation db_xref evidence function gene label map note partial standard_name usedin\n" +
          "5'clip          citation db_xref function gene evidence label map note partial standard_name usedin\n" +
          "5'UTR           citation db_xref evidence function gene label map note partial standard_name usedin\n" +
          "-10_signal      citation db_xref evidence gene label map partial note standard_name usedin\n" +
          "-35_signal      citation db_xref evidence gene label map note partial standard_name usedin";
      } else {
        if (file_name.equals ("etc/qualifier_types")) {
          buffer =
            "allele           no         \"text\"\n" +
            "anticodon        yes        (::)    pos aa\n" +
            "bound_moiety     no         \"text\"\n" +
            "cell_line        no         \"text\"\n" +
            "cell_type        no         \"text\"\n" +
            "chromosome       no         \"opt\"\n" +
            "chloroplast      no         \"opt\"\n" +
            "chromoplast      no         \"opt\"\n" +
            "citation         no         ref\n" +
            "clone            no         \"text\"\n" +
            "clone_lib        no         \"text\"\n" +
            "codon            no         (::)    seq aa\n" +
            "codon_start      yes        number  1 3\n" +
            "cons_splice      yes        (::)    5'site 3'site\n" +
            "country          no         \"text\"\n" +
            "cultivar         no         \"text\"\n" +
            "cyanelle         no         \"opt\"\n" +
            "db_xref          no         \"text\"\n" +
            "dev_stage        no         \"text\"\n" +
            "direction        yes        list    LEFT RIGHT BOTH\n" +
            "EC_number        no         \"text\"\n" +
            "evidence         yes        list    EXPERIMENTAL NOT_EXPERIMENTAL\n" +
            "exception        no         \"text\"\n" +
            "focus            no         none\n" +
            "frequency        yes        real    0.0  1.0\n" +
            "function         yes        \"text\"\n" +
            "gene             no         \"text\"\n" +
            "germline         yes        none\n" +
            "haplotype        no         \"text\"\n" +
            "insertion_seq    no         \"text\"\n" +
            "isolate          no         \"text\"\n" +
            "kinetoplast      no         \"opt\"\n" +
            "label            yes        item\n" +
            "lab_host         no         \"text\"\n" +
            "map              no         \"text\"\n" +
            "macronuclear     no         none\n" +
            "mitochondrion    no         \"opt\"\n" +
            "mod_base         no         modbase\n" +
            "note             no         \"text\"\n" +
            "number           yes        number  1 99999999\n" +
            "organism         yes        \"text\"\n" +
            "partial          yes        none\n" +
            "PCR_conditions   no         \"text\"\n" +
            "pop_variant      no         \"text\"\n" +
            "phenotype        no         \"text\"\n" +
            "plasmid          no         \"text\"\n" +
            "product          no         \"text\"\n" +
            "protein_id       no         \"text\"\n" +
            "proviral         yes        none\n" +
            "pseudo           yes        none\n" +
            "rearranged       yes        none\n" +
            "replace          no         \"text\"\n" +
            "rpt_family       no         \"text\"\n" +
            "rpt_type         no         list    TANDEM INVERTED FLANKING TERMINAL DIRECT DISPERSED OTHER\n" +
            "rpt_unit         no         location\n" +
            "sequenced_mol    no         \"list\"  \"cDNA\" \"cDNA to genomic RNA\" \"cDNA to mRNA\" \"cDNA to other RNA\" \"cDNA to rRNA\" \"DNA\" \"mRNA\" \"RNA\" \"rRNA\" \"scRNA\" \"snRNA\" \"tRNA\"\n" +
            "serotype         no         \"text\"\n" +
            "sex              no         \"text\"\n" +
            "specific_host    no         \"text\"\n" +
            "specimen_voucher no          \"text\"\n" +
            "standard_name    no         \"text\"\n" +
            "strain           no         \"text\"\n" +
            "sub_clone        no         \"text\"\n" +
            "sub_species      no         \"text\"\n" +
            "sub_strain       no         \"text\"\n" +
            "tissue_lib       no         \"text\"  \n" +
            "tissue_type      no         \"text\"\n" +
            "translation      no         \"text\"\n" +
            "transl_except    no         (::)    pos aa\n" +
            "transl_table     no         number  1 11\n" +
            "transposon       no         \"text\"\n" +
            "type             no         \"text\"\n" +
            "usedin           no         feature\n" +
            "variety          no         \"text\"\n" +
            "virion           no         none\n";
        } else {
          buffer = null;
        }
      }
    }

    return new ByteArrayInputStream (buffer.getBytes ());
  }

  /**
   *  Returns a Vector containing the possible Entry sources for this
   *  application.
   *  @param frame The component that is creating the EntrySource objects.
   *    (Used for requesters.)
   *  @param listener InputStreamProgressEvent objects will be sent to this
   *    listener as progress on reading is made.
   **/
  public static EntrySourceVector
    getEntrySources (final Frame frame,
                     final InputStreamProgressListener listener) {

    final EntrySourceVector return_vector = new EntrySourceVector ();

    return return_vector;
  }

  /**
   *  Return a Logger for warnings/errors/messages.
   **/
  public static Logger getLogger () {
    return new Logger () {
      public void log (final String message) {
        // don't do any logging
      }

      /**
       *  Read from the given Reader and send it to the log.
       **/
      public void log (final Reader reader)
          throws IOException {
        // don't do any logging
      }
    };
  }
}
